autosubmit.monitor — autosubmit 3.9.1 documentation

# autosubmit.monitor

class `autosubmit.monitor.monitor.` `Monitor`

  Class to handle monitoring of Jobs at HPC.

  static `clean_plot`(expid)

    Function to clean space on BasicConfig.LOCAL_ROOT_DIR/plot directory. Removes all plots except last two.

    Parameters: | expid (str) – experiment’s identifier

  static `clean_stats`(expid)

    Function to clean space on BasicConfig.LOCAL_ROOT_DIR/plot directory. Removes all stats’ plots except last two.

    Parameters: | expid (str) – experiment’s identifier

  static `color_status`(status)

    Return color associated to given status

    Parameters: | status (Status) – status
    Returns: | color
    Return type: | str

  `create_tree_list`(expid, joblist, packages, groups, hide_groups=False)

    Create graph from joblist

    Parameters: | expid (str) – experiment’s identifier joblist (JobList) – joblist to plot
    Returns: | created graph
    Return type: | pydotplus.Dot

  `generate_output`(expid, joblist, path, output_format='pdf', packages=None, show=False, groups={}, hide_groups=False, job_list_object=None)

    Plots graph for joblist and stores it in a file

    Parameters: | expid (str) – experiment’s identifier joblist (List of Job objects) – list of jobs to plot output_format (str (png, pdf, ps)) – file format for plot show (bool) – if true, will open the new plot with the default viewer job_list_object (JobList object) – Object that has the main txt generation method

  `generate_output_stats`(expid, joblist, output_format='pdf', period_ini=None, period_fi=None, show=False)

    Plots stats for joblist and stores it in a file

    Parameters: | expid (str) – experiment’s identifier joblist (JobList) – joblist to plot output_format (str (png, pdf, ps)) – file format for plot period_ini (datetime) – initial datetime of filtered period period_fi (datetime) – final datetime of filtered period show (bool) – if true, will open the new plot with the default viewer

  `generate_output_txt`(expid, joblist, path, classictxt=False, job_list_object=None)

    Function that generates a representation of the jobs in a txt file :param expid: experiment’s identifier :type expid: str :param joblist: experiment’s list of jobs :type joblist: list :param job_list_object: Object that has the main txt generation method :type job_list_object: JobList object